Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(212)

Unified Diff: third_party/WebKit/Source/core/frame/FrameView.h

Issue 2845583002: Remove FrameViewBase as base class of RemoteFrameView. (Closed)
Patch Set: ConvertSelfToChild take FrameOrPlugin as arg Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/frame/FrameView.h
diff --git a/third_party/WebKit/Source/core/frame/FrameView.h b/third_party/WebKit/Source/core/frame/FrameView.h
index a1d552cb17c1e9e75c3464d24302ef7bfb57d68e..2292cf01c9749f1d60d9a9bf993a26685ea5eae4 100644
--- a/third_party/WebKit/Source/core/frame/FrameView.h
+++ b/third_party/WebKit/Source/core/frame/FrameView.h
@@ -40,7 +40,6 @@
#include "core/paint/PaintInvalidationCapableScrollableArea.h"
#include "core/paint/PaintPhase.h"
#include "core/paint/ScrollbarManager.h"
-#include "core/plugins/PluginView.h"
#include "platform/FrameViewBase.h"
#include "platform/RuntimeEnabledFeatures.h"
#include "platform/animation/CompositorAnimationHost.h"
@@ -480,8 +479,7 @@ class CORE_EXPORT FrameView final
// and repaints to the host window in the window's coordinate space.
PlatformChromeClient* GetChromeClient() const;
- typedef HeapHashSet<Member<FrameViewBase>> ChildrenSet;
- typedef HeapHashSet<Member<PluginView>> PluginsSet;
+ typedef HeapHashSet<Member<FrameOrPlugin>> ChildrenSet;
typedef HeapHashSet<Member<Scrollbar>> ScrollbarsSet;
// Functions for child manipulation and inspection.
@@ -494,16 +492,13 @@ class CORE_EXPORT FrameView final
bool IsVisible() const {
return self_visible_ && parent_visible_;
} // Whether or not we are actually visible.
- void SetParentVisible(bool);
+ void SetParentVisible(bool) override;
void SetSelfVisible(bool v) { self_visible_ = v; }
- void SetParent(FrameViewBase*) override;
- FrameViewBase* Parent() const override { return parent_; }
- void RemoveChild(FrameViewBase*);
- void AddChild(FrameViewBase*);
- const ChildrenSet* Children() const { return &children_; }
- void RemovePlugin(PluginView*);
- void AddPlugin(PluginView*);
- const PluginsSet* Plugins() const { return &plugins_; }
+ void SetParent(FrameView*) override;
+ FrameView* Parent() const override { return parent_; }
+ void RemoveChild(FrameOrPlugin*);
+ void AddChild(FrameOrPlugin*);
+ const ChildrenSet& Children() const { return children_; }
void RemoveScrollbar(Scrollbar*);
void AddScrollbar(Scrollbar*);
const ScrollbarsSet* Scrollbars() const { return &scrollbars_; }
@@ -653,10 +648,9 @@ class CORE_EXPORT FrameView final
IntRect ConvertToRootFrame(const IntRect&) const;
IntPoint ConvertToRootFrame(const IntPoint&) const;
- IntPoint ConvertSelfToChild(const FrameViewBase*, const IntPoint&) const;
+ IntPoint ConvertSelfToChild(const FrameOrPlugin&, const IntPoint&) const;
- // FrameViewBase override. Handles painting of the contents of the view as
- // well as the scrollbars.
+ // Handles painting of the contents of the view as well as the scrollbars.
void Paint(GraphicsContext&, const CullRect&) const override;
void Paint(GraphicsContext&, const GlobalPaintFlags, const CullRect&) const;
void PaintContents(GraphicsContext&,
@@ -1069,7 +1063,7 @@ class CORE_EXPORT FrameView final
EmbeddedObjectSet part_update_set_;
// FIXME: These are just "children" of the FrameView and should be
- // Member<FrameViewBase> instead.
+ // Member<FrameView> instead.
HashSet<RefPtr<LayoutPart>> parts_;
Member<LocalFrame> frame_;
@@ -1149,7 +1143,6 @@ class CORE_EXPORT FrameView final
bool vertical_scrollbar_lock_;
ChildrenSet children_;
- PluginsSet plugins_;
ScrollbarsSet scrollbars_;
ScrollOffset pending_scroll_delta_;
@@ -1180,7 +1173,7 @@ class CORE_EXPORT FrameView final
// Paint properties for SPv2 Only.
// The hierarchy of transform subtree created by a FrameView.
// [ preTranslation ] The offset from FrameViewBase::frameRect.
// | Establishes viewport.
// +---[ scrollTranslation ] Frame scrolling.
// TODO(trchen): These will not be needed once settings->rootLayerScrolls() is
@@ -1272,6 +1265,11 @@ DEFINE_TYPE_CASTS(FrameView,
frameViewBase,
frameViewBase->IsFrameView(),
frameViewBase.IsFrameView());
+DEFINE_TYPE_CASTS(FrameView,
+ FrameOrPlugin,
+ frame_or_plugin,
+ frame_or_plugin->IsFrameView(),
+ frame_or_plugin.IsFrameView());
DEFINE_TYPE_CASTS(FrameView,
ScrollableArea,
scrollableArea,
@@ -1180,7 +1173,7 @@ class CORE_EXPORT FrameView final
// Paint properties for SPv2 Only.
// The hierarchy of transform subtree created by a FrameView.
- // [ preTranslation ] The offset from FrameViewBase::frameRect.
+ // [ preTranslation ] The offset from FrameView::FrameRect.
// | Establishes viewport.
// +---[ scrollTranslation ] Frame scrolling.

Powered by Google App Engine
This is Rietveld 408576698